# begin: Platecom header
# -*- coding: latin-1 -*-
# vim: set ts=4 sts=4 sw=4 :
#
# $Id: mailman.py 235 2008-06-10 20:21:40Z crocha $
#
# end: Platecom header
"""Definition of the Adqnews content type.
"""

import sys
import re
import urllib
import urlparse

from zope.component import queryUtility
from zope.interface import implements, implementer
from zope.component import adapts, adapter
from zope.app.schema.vocabulary import IVocabularyFactory

from Products.CMFCore.utils import getToolByName
from Products.Archetypes import atapi
from Products.ATContentTypes.content.base import ATCTContent, registerATCT
from Products.ATContentTypes.content.schemata import ATContentTypeSchema

from icnews.acquire.interfaces import IAdqnews, IRSS2Feed
from icnews.acquire.config import PROJECTNAME
from icnews.acquire import ICNewsAquireMessageFactory as _


AdqnewsSchema = atapi.BaseSchema.copy() + atapi.Schema((
	atapi.StringField('source',
		required=True,
		default='',
		validators=('isURL',),
		widget=atapi.StringWidget(
			label_msgid='label_adqnews_source',
			label='Source',
			description_msgid='help_adqnews_source',
			description='A URL from where to acquire news.')
	),
	atapi.StringField('re',
		required=False,
		default='',
		widget=atapi.LinesWidget(
			label_msgid='label_adqnews_re',
			label='Regular Expresion',
			description_msgid='help_adqnews_re',
			description='A regular expresion to parse the web page.')
	),
	atapi.StringField('encoding',
		required=True,
		default='',
		vocabulary='encodings_vocabulary',
		widget=atapi.SelectionWidget(
			label="Encoding",
			label_msgid='label_adqnews_encoding',
			description_msgid='help_adqnews_encoding',
			description='The encoding of the source page.')
	),
))

AdqnewsSchema['description'].schemata = 'default'


class Adqnews(ATCTContent):
	"""Implementation of the Adqnews type"""
	implements(IAdqnews)

	portal_type = "Adqnews"
	_at_rename_after_creation = True
	schema = AdqnewsSchema

	#source = atapi.ATFieldProperty('source')
	#re = atapi.ATFieldProperty('re')

	def encodings_vocabulary(self):
		"""Just a wrapper for the encodings vocabulary in
		icsemantic.thesaurus
		"""
		#import pdb; pdb.set_trace()
		vocab = queryUtility(IVocabularyFactory,
							 name=u'icsemantic.core.encodings')
		simple_vocab = [(i.token, i.title) for i in
						vocab(None)]
		return atapi.DisplayList(simple_vocab)



@adapter(IAdqnews)
@implementer(IRSS2Feed)
def url2rss2(context):
	"""Genera un contenido rss a partir de una url y una expresión
	regular. La expresión regular (regexp) debe tener grupos de
	matching nombrados como:
	title: titulo de la noticia.
	link: url que nos lleva a la noticia
	description: descripción de la noticia.

	El title (titulo) de la función corresponde al titulo del canal rss
	de donde se saco la noticia. También hay que definir la url (link)
	de la página a parsear, y una descripción del canal (description).
	Muchas páginas no tienen definido la codificación de los caracteres
	(encoding), con lo que es recomendable asigarnle uno.
	"""
	title = context.Title()
	link = context.getSource()
	description = context.Description()
	encoding = context.getEncoding()
	regexp = "".join(context.getRe())

	f=urllib.urlopen(link)
	s=''.join(f.readlines())

	o_rss = re.compile(regexp, re.S)

	r = o_rss.finditer(s)

	s = """\
<?xml version="1.0" encoding="%s"?>
<rss version="2.0">
  <channel>
	<title>%s</title>
	<link>%s</link>
	<description>%s</description>
""" % (encoding, unicode(title, sys.stdin.encoding),
	   unicode(link, sys.stdin.encoding),
	   unicode(description, sys.stdin.encoding))
	for i in r:
		si = i.groupdict()
		if 'title' in si and si['title']:
			s += "  <item>\n"
			s += "	 <title>%s</title>\n" % si['title'].decode(encoding)
			if 'link' in si and si['link']:
				s += "	 <link>%s</link>\n" % urlparse.urljoin(link, si['link'])
			if 'description' in si and si['description']:
				s += "	 <description>%s</description>\n" % si['description'].decode(encoding)
			s += "  </item>\n"
	s += """
  </channel>
</rss>"""

	return s

registerATCT(Adqnews, PROJECTNAME)
